;; Generated package description from dired-duplicates.el  -*- no-byte-compile: t -*-
(define-package "dired-duplicates" "0.4" "Find duplicate files locally and remotely" '((emacs "27.1")) :commit "5c5f24bea92159987f65f01ef32b261e905997bd" :authors '(("Harald Judt" . "h.judt@gmx.at")) :maintainer '("Harald Judt" . "h.judt@gmx.at") :keywords '("files") :url "https://codeberg.org/hjudt/dired-duplicates")
